Learn R Programming

npregfast (version 1.3.0)

allotest: Bootstrap based test for testing an allometric model

Description

Bootstrap-based procedure that tests whether the data can be modelled by an allometric model.

Usage

allotest(formula, data = data, nboot = 500, kbin = 200, seed = NULL)

Arguments

formula
An object of class formula: a sympbolic description of the model to be fitted.
data
A data frame argumment or matrix containing the model response variable and covariates required by the formula.
nboot
Number of bootstrap repeats.
kbin
Number of binning nodes over which the function is to be estimated.
seed
Seed to be used in the bootstrap procedure.

Value

An object is returned with the following elements:
statistic
the value of the test statistic.
value
the p-value of the test.

Details

In order to facilitate the choice of a model appropriate to the data while at the same time endeavouring to minimise the loss of information, a bootstrap-based procedure, that test whether the data can be modelled by an allometric model, was developed. Therefore, allotest tests the null hypothesis of an allometric model taking into account the logarithm of the original variable ($$ and $$). Based on a general model of the type $$Y^*=m(X^*)+\varepsilon$$ the aim here is to test the null hypothesis of an allometric model $$H_0 = m(x^*) = a^*+ b^* x^*$$ $$ the general hypothesis $$, with $$ being an unknown nonparametric function; or analogously, $$H_1: m(x^*)= a^*+ b^* x^* + g(x^*)$$ with $$ being an unknown function not equal to zero.

To implement this test we have used the wild bootstrap.

References

Sestelo, M. and Roca-Pardinas, J. (2011). A new approach to estimation of length-weight relationship of $Pollicipes$ $pollicipes$ (Gmelin, 1789) on the Atlantic coast of Galicia (Northwest Spain): some aspects of its biology and management. Journal of Shellfish Research, 30 (3), 939--948.

Sestelo, M. (2013). Development and computational implementation of estimation and inference methods in flexible regression models. Applications in Biology, Engineering and Environment. PhD Thesis, Department of Statistics and O.R. University of Vigo.

Examples

Run this code
library(npregfast)
data(barnacle)
allotest(DW ~ RC, data = barnacle, nboot = 100, seed = 130853)

Run the code above in your browser using DataLab