allotest(formula, data = data, nboot = 500, kbin = 200, seed = NULL)formula: a sympbolic description
of the model to be fitted.formula.allotest tests the null hypothesis of an allometric model taking
into account the logarithm of the original variable
($X^* = log(X)$ and $Y^* =log (Y)$).
Based on a general model of the type
$$Y^*=m(X^*)+\varepsilon$$
the aim here is to test the null hypothesis of an allometric model
$$H_0 = m(x^*) = a^*+ b^* x^*$$
$vs.$ the general hypothesis
$H_1$, with $m$
being an unknown nonparametric function; or analogously,
$$H_1: m(x^*)= a^*+ b^* x^* + g(x^*)$$
with $g(x^*)$ being an unknown function not equal to zero. To implement this test we have used the wild bootstrap.
Sestelo, M. (2013). Development and computational implementation of estimation and inference methods in flexible regression models. Applications in Biology, Engineering and Environment. PhD Thesis, Department of Statistics and O.R. University of Vigo.
library(npregfast)
data(barnacle)
allotest(DW ~ RC, data = barnacle, nboot = 100, seed = 130853)Run the code above in your browser using DataLab