globaltest(formula, data = data, der, weights = NULL, nboot = 500,
h0 = -1, h = -1, nh = 30, kernel = "epanech", p = 3, kbin = 100,
seed = NULL)formula: a sympbolic description
of the model to be fitted.formula.der is NULL. If this term is 0,
the testing procedures is applied for the estimate. If it is 1 or
2, it is designed for the first h is discretised, to speed up computation.kernel = "epanech", where the Epanechnikov
density function kernel will be used. Also, several types of kernel funcitons
can be used: triangular and Gaussian density function,
globaltest can be used to test the equality of the $M$
curves specific to each level. This bootstrap based test assumes the
following null hypothesis:$$H_0^r: m_1^r(\cdot) = \ldots = m_M^r(\cdot)$$
versus the general alternative
$$H_1^r: m_i^r (\cdot) \ne m_j^r (\cdot) \quad \rm{for} \quad \rm{some} \quad \emph{i}, \emph{j} \in { 1, \ldots, M}.$$
Note that, if $H_0$ is not rejected, then the equality of critical points will also accepted.
To test the null hypothesis, it is used a test statistic, $T$, based on direct nonparametric estimates of the curves.
If the null hypothesis is true, the $T$ value should be close to zero but is generally greater. The test rule based on $T$ consists of rejecting the null hypothesis if $T > T^{1- \alpha}$, where $T^p$ is the empirical $p$-percentile of $T$ under the null hypothesis. To obtain this percentile, we have used bootstrap techniques. See details in references.
library(npregfast)
data(barnacle)
globaltest(DW ~ RC : F, data = barnacle, der = 1, seed = 130853, nboot = 100)Run the code above in your browser using DataLab